// Load data from the CSV file
d3.csv(
  'https://gist.githubusercontent.com/SirishaManthena/bbd9bc8ac42c20187d72b7bf8464d4a0/raw/c784a4768f539abd56c24b95c6efbf0c9e4c9f12/tesla.csv',
)
  .then(function (data) {
    console.log(data); // Log loaded data to console for verification

    // Parse data
    const parseDate = d3.timeParse('%Y-%m-%d');
    data.forEach(function (d) {
      d.DateTime = parseDate(d.DateTime); // Parse dates
      d.Close = +d.Close; // Convert string to number
    });

    console.log(data); // Log parsed data to console for verification

    // Set up dimensions
    const margin = {
      top: 20,
      right: 30,
      bottom: 30,
      left: 60,
    };
    const width = 800 - margin.left - margin.right;
    const height = 400 - margin.top - margin.bottom;

    // Create SVG element
    const svg = d3
      .select('#chart-container')
      .append('svg')
      .attr('width', width + margin.left + margin.right)
      .attr('height', height + margin.top + margin.bottom)
      .append('g')
      .attr(
        'transform',
        'translate(' + margin.left + ',' + margin.top + ')',
      );

    // Set up scales
    const x = d3
      .scaleTime()
      .domain(d3.extent(data, (d) => d.DateTime))
      .range([0, width]);

    const y = d3
      .scaleLinear()
      .domain([0, d3.max(data, (d) => d.Close)])
      .range([height, 0]);

    console.log('x domain:', x.domain()); // Log x domain to console for verification
    console.log('y domain:', y.domain()); // Log y domain to console for verification

    // Draw line
    const line = d3
      .line()
      .x((d) => x(d.DateTime))
      .y((d) => y(d.Close));

    svg
      .append('path')
      .datum(data)
      .attr('fill', 'none')
      .attr('stroke', 'steelblue')
      .attr('stroke-width', 2)
      .attr('d', line);

    // Add x axis
    svg
      .append('g')
      .attr('transform', 'translate(0,' + height + ')')
      .call(d3.axisBottom(x));

    // Add y axis
    svg.append('g').call(d3.axisLeft(y));

    // Add x axis label
    svg
      .append('text')
      .attr(
        'transform',
        'translate(' +
          width / 2 +
          ' ,' +
          (height + margin.top + 10) +
          ')',
      )
      .style('text-anchor', 'middle')
      .text('Date');

    // Add y axis label
    svg
      .append('text')
      .attr('transform', 'rotate(-90)')
      .attr('y', 0 - margin.left)
      .attr('x', 0 - height / 2)
      .attr('dy', '1em')
      .style('text-anchor', 'middle')
      .text('Close Price');
  })
  .catch(function (error) {
    console.log(error);
  });
